--------------------------------------------------------------------------------
-- Copyright (c) 2004 Atmark Techno,Inc. All Rights Reserved.
--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;
use IEEE.std_logic_unsigned.all;
LIBRARY UNISIM;
USE UNISIM.VCOMPONENTS.ALL;

ENTITY top IS
PORT (
	SYS_Rst_IN : IN STD_LOGIC;
	SYS_CLK_IN : IN STD_LOGIC;
	SYS_CLK_OUT : OUT STD_LOGIC;
	RAM_CLK : IN STD_LOGIC;
	LA : OUT STD_LOGIC_VECTOR(0 TO 22);
	LD : INOUT STD_LOGIC_VECTOR(0 TO 15);
	RAM_DQM : OUT STD_LOGIC_VECTOR(0 TO 1);
	RAM_BS : OUT STD_LOGIC_VECTOR(0 TO 1);
	RAM_CSn : OUT STD_LOGIC;
	RAM_RASn : OUT STD_LOGIC;
	RAM_CASn : OUT STD_LOGIC;
	RAM_WEn : OUT STD_LOGIC;
	RAM_CKE : OUT STD_LOGIC;
	FLASH_CEn : OUT STD_LOGIC;
	FLASH_OEn : OUT STD_LOGIC;
	FLASH_WEn : OUT STD_LOGIC;
	FLASH_BYTEn : OUT STD_LOGIC;
	FLASH_RnB : IN STD_LOGIC;
	MAC_AEN : OUT STD_LOGIC;
	MAC_WRn : OUT STD_LOGIC;
	MAC_RDn : OUT STD_LOGIC;
	MAC_INTR : IN STD_LOGIC;
	MAC_BEn : OUT STD_LOGIC_VECTOR(0 TO 1);
	MAC_ARDY : IN STD_LOGIC;
	MAC_ADSn : OUT STD_LOGIC;
	CNSL_RX : IN STD_LOGIC;
	CNSL_TX : OUT STD_LOGIC;
	CNSL_CTSn : IN STD_LOGIC;
	CNSL_RTSn : OUT STD_LOGIC;
	LEDn : OUT STD_LOGIC;
	BOOTMODE : IN STD_LOGIC;
	BUS_REL : IN STD_LOGIC;
	BUS_REQ : OUT STD_LOGIC;
	RESERVE_COLLECT : OUT STD_LOGIC;
	FPGA_RESET_EN : INOUT STD_LOGIC

);

END top;

ARCHITECTURE IMP OF top IS

CONSTANT DEFAULT_CLKFX_MULTIPLY : integer := 14;
CONSTANT COMPATIBLE_32MBIT : std_logic := '0' ;

COMPONENT xps_proj 
PORT (
	SYS_Rst : IN STD_LOGIC;
	SYS_CLK : IN STD_LOGIC;
	SDRAM_core_clk 	: IN STD_LOGIC;
	SDRAM_ADR 		: OUT STD_LOGIC_VECTOR(0 TO 11);
	SDRAM_DQ_O 		: OUT STD_LOGIC_VECTOR(0 TO 15);
	SDRAM_DQ_I 		: IN STD_LOGIC_VECTOR(0 TO 15);
	SDRAM_DQ_T 		: OUT STD_LOGIC_VECTOR(0 TO 15);
	SDRAM_BankAddr 	: OUT STD_LOGIC_VECTOR(0 TO 1);
	SDRAM_DQM		: OUT STD_LOGIC_VECTOR(0 TO 1);
	SDRAM_RASn 		: OUT STD_LOGIC;
	SDRAM_CASn 		: OUT STD_LOGIC;
	SDRAM_CSn 		: OUT STD_LOGIC;
	SDRAM_WEn 		: OUT STD_LOGIC;
	SDRAM_Clk 		: OUT STD_LOGIC;
	SDRAM_CKE 		: OUT STD_LOGIC;
	MEMCON_OEn 		: OUT STD_LOGIC_VECTOR(0 TO 1);
	MEMCON_WEn 		: OUT STD_LOGIC;
	MEMCON_ADR 		: OUT STD_LOGIC_VECTOR(0 TO 31);
	MEMCON_DQ_O 	: OUT STD_LOGIC_VECTOR(0 TO 15);
	MEMCON_DQ_I 	: IN STD_LOGIC_VECTOR(0 TO 15);
	MEMCON_DQ_T 	: OUT STD_LOGIC_VECTOR(0 TO 15);
	MEMCON_CEn 		: OUT STD_LOGIC_VECTOR(0 TO 1);
	MEMCON_BEn		: OUT STD_LOGIC_VECTOR(0 to 1);
	MAC_INTERRUPT_IN : IN STD_LOGIC;
	CONSOLE_TX 		: OUT STD_LOGIC;
	CONSOLE_RX 		: IN STD_LOGIC;
	GPIO_IO_0_I 	: IN STD_LOGIC_VECTOR(0 to 2);
	GPIO_IO_0_O 	: OUT STD_LOGIC_VECTOR(0 to 2);
	GPIO_IO_0_T 	: OUT STD_LOGIC_VECTOR(0 to 2)
);
END COMPONENT;

COMPONENT IBUFG 
PORT (
	O : OUT STD_LOGIC;
	I : IN STD_LOGIC);
END COMPONENT;

COMPONENT OBUF 
PORT (
	O : OUT STD_LOGIC;
	I : IN STD_LOGIC);
END COMPONENT;

COMPONENT BUFG 
PORT (
	O : OUT STD_LOGIC;
	I : IN STD_LOGIC);
END COMPONENT;

COMPONENT IOBUF 
PORT (
	O : OUT STD_LOGIC;
	I : IN STD_LOGIC;
	IO : INOUT STD_LOGIC;
	T : IN STD_LOGIC);
END COMPONENT;
 
COMPONENT DCM
    generic( 
       CLKDV_DIVIDE : real := 2.0;
       CLKFX_DIVIDE : integer := 1;
       CLKFX_MULTIPLY : integer := 4;
       CLKIN_DIVIDE_BY_2 : boolean := false;
       CLKIN_PERIOD : real := 0.0;                         
       CLKOUT_PHASE_SHIFT : string := "NONE";
       CLK_FEEDBACK : string := "1X";
       DESKEW_ADJUST : string := "SYSTEM_SYNCHRONOUS";     
       DFS_FREQUENCY_MODE : string := "LOW";
       DLL_FREQUENCY_MODE : string := "LOW";
       DSS_MODE : string := "NONE";                        
       DUTY_CYCLE_CORRECTION : boolean := true;
       FACTORY_JF : bit_vector := X"C080";                 
       MAXPERCLKIN : time := 1000000 ps;                   
       MAXPERPSCLK : time := 100000000 ps;                 
       PHASE_SHIFT : integer := 0;
       SIM_CLKIN_CYCLE_JITTER : time := 300 ps;            
       SIM_CLKIN_PERIOD_JITTER : time := 1000 ps;          
       STARTUP_WAIT : boolean := false                     
     );
     port (
       CLKIN : in std_logic;
       CLKFB : in std_logic;
       RST : in std_logic;
       PSEN : in std_logic;
       PSINCDEC : in std_logic;
       PSCLK : in std_logic;
       DSSEN : in std_logic;
       CLK0 : out std_logic;
       CLK90 : out std_logic;
       CLK180 : out std_logic;
       CLK270 : out std_logic;
       CLKDV : out std_logic;
       CLK2X : out std_logic;
       CLK2X180 : out std_logic;
       CLKFX : out std_logic;
       CLKFX180 : out std_logic;
       STATUS : out std_logic_vector (7 downto 0);
       LOCKED : out std_logic;
       PSDONE : out std_logic
       );


END COMPONENT;



	SIGNAL LED_I : STD_LOGIC_VECTOR(0 TO 19);
	SIGNAL LED_O : STD_LOGIC_VECTOR(0 TO 19);
	SIGNAL LED_T : STD_LOGIC_VECTOR(0 TO 19);
	SIGNAL MEMCON_DQ_I : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL MEMCON_DQ_O : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL MEMCON_DQ_T : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL SDRAM_DQ_I : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL SDRAM_DQ_O : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL SDRAM_DQ_T : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL SYS_CLK : STD_LOGIC;
	SIGNAL SYS_Rst : STD_LOGIC;
	SIGNAL SDRAM_ADR  : STD_LOGIC_VECTOR(0 TO 11);
	SIGNAL MEMCON_ADR : STD_LOGIC_VECTOR(0 TO 31);
	SIGNAL MEMCON_CEn : STD_LOGIC_VECTOR(0 TO 1);
	SIGNAL MEMCON_OEn : STD_LOGIC_VECTOR(0 TO 1);
	SIGNAL MEMCON_WEn : STD_LOGIC;
	SIGNAL MEMCON_CEn_w : STD_LOGIC;
	SIGNAL MEMCON_BEn	: STD_LOGIC_VECTOR(0 to 1);
	SIGNAL LD_O_w : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL LD_T_w : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL LD_IN : STD_LOGIC_VECTOR(0 TO 15);
	SIGNAL LA_w : STD_LOGIC_VECTOR(0 TO 22);
	SIGNAL bootram_dout : STD_LOGIC_VECTOR(0 TO 31);
	SIGNAL bootram_we_w : STD_LOGIC;
	SIGNAL SDRAM_Clk : STD_LOGIC;
	SIGNAL SDRAM_Clk_i : STD_LOGIC;
	SIGNAL SYS_CLK_dll_in : STD_LOGIC;
	SIGNAL SYS_CLK_dll_out : STD_LOGIC;
	SIGNAL SYS_CLK_dll_fb : STD_LOGIC;
	SIGNAL SYS_CLK_dll_2x : STD_LOGIC;
	SIGNAL RAM_CLK_w : STD_LOGIC;
	SIGNAL SDRAM_CLK_dll_out : STD_LOGIC;
	SIGNAL SDRAM_core_clk : STD_LOGIC;
	SIGNAL DLL_LOCK : STD_LOGIC;
	SIGNAL SYS_CLK_RAM_OUT : STD_LOGIC;
	SIGNAL not_sig : STD_LOGIC;
	SIGNAL DLL_LOCK_o : STD_LOGIC;
	SIGNAL DLL_LOCK_n : STD_LOGIC;
	SIGNAL GPIO_IO_0_I 	: STD_LOGIC_VECTOR(0 to 2);
	SIGNAL GPIO_IO_0_O 	: STD_LOGIC_VECTOR(0 to 2);
	SIGNAL memcon_adr_change : STD_LOGIC_VECTOR(0 to 3);

BEGIN


-- System clock generate
IBUFG_1 : IBUFG
PORT MAP (
	I => SYS_CLK_IN,
	O => SYS_CLK_dll_in
);

BUF_1 : BUFG
PORT MAP (
	I => SYS_CLK_dll_out,
	O => SYS_CLK_dll_fb
);
BUF_2 : BUFG
PORT MAP (
	I => SYS_CLK_dll_2x,
	O => SYS_CLK
);

not_sig <= SYS_Rst_IN;


U_DCM: DCM  
    Generic map (
      CLK_FEEDBACK => "NONE",
      CLKDV_DIVIDE => 2.0,
      CLKFX_DIVIDE => 1,
      CLKFX_MULTIPLY => DEFAULT_CLKFX_MULTIPLY,
      CLKIN_DIVIDE_BY_2 => FALSE,
      CLKIN_PERIOD => 271.267,
      CLKOUT_PHASE_SHIFT => "FIXED",
      DESKEW_ADJUST => "SYSTEM_SYNCHRONOUS",
      DFS_FREQUENCY_MODE => "LOW",
      DLL_FREQUENCY_MODE => "LOW",
      DUTY_CYCLE_CORRECTION => FALSE,
      PHASE_SHIFT => 0,
      STARTUP_WAIT => FALSE)
     port map (
      CLKIN => SYS_CLK_dll_in,
      CLKFB => '0',
      RST => not_sig,
      PSEN => '0',
      PSINCDEC => '0',
      PSCLK => '0',
      DSSEN => '0',
      CLKFX => SYS_CLK_dll_2x,
      LOCKED => DLL_LOCK_o);


-- SDRAM clock generate
OBUF_2 : OBUF
PORT MAP (
	I => SYS_CLK_dll_2x,
	O => SYS_CLK_OUT
);
IBUFG_2 : IBUFG
PORT MAP (
	I => RAM_CLK,
	O => RAM_CLK_w
);

DLL_LOCK_n <= not DLL_LOCK_o;



xps_proj_i : xps_proj
PORT MAP (
	MEMCON_CEn => MEMCON_CEn,
	SYS_CLK => SYS_CLK,
	SDRAM_core_clk => SYS_CLK,
	SDRAM_CKE => RAM_CKE,
	MEMCON_OEn => MEMCON_OEn,
	SDRAM_Clk => SDRAM_Clk,
	CONSOLE_RX => CNSL_RX,
	SYS_Rst => SYS_Rst,
	SDRAM_RASn => RAM_RASn,
	SDRAM_CASn => RAM_CASn,
	MEMCON_WEn => MEMCON_WEn,
	SDRAM_WEn => RAM_WEn,
	SDRAM_DQM => RAM_DQM,
	SDRAM_CSn => RAM_CSn,
	SDRAM_BankAddr => RAM_BS,
	CONSOLE_TX => CNSL_TX,
	MEMCON_ADR => MEMCON_ADR,
	MEMCON_BEn => MEMCON_BEn,
	SDRAM_ADR => SDRAM_ADR,
	SDRAM_DQ_O => SDRAM_DQ_O,
	SDRAM_DQ_I => SDRAM_DQ_I,
	SDRAM_DQ_T => SDRAM_DQ_T,
	MAC_INTERRUPT_IN => MAC_INTR,
	MEMCON_DQ_O => MEMCON_DQ_O,
	MEMCON_DQ_I => MEMCON_DQ_I,
	MEMCON_DQ_T => MEMCON_DQ_T,
	GPIO_IO_0_I => GPIO_IO_0_I,
	GPIO_IO_0_O => GPIO_IO_0_O
);


-- Free RS232C
CNSL_RTSn <= CNSL_CTSn;

-- Free LED
LEDn <= '0';




-- Address bus tri state buffer
OBUFT_0 : OBUFT
PORT MAP (
	O => LA(0),
	I => LA_w(0),
	T => SYS_Rst);
OBUFT_1 : OBUFT
PORT MAP (
	O => LA(1),
	I => LA_w(1),
	T => SYS_Rst);
OBUFT_2 : OBUFT
PORT MAP (
	O => LA(2),
	I => LA_w(2),
	T => SYS_Rst);
OBUFT_3 : OBUFT
PORT MAP (
	O => LA(3),
	I => LA_w(3),
	T => SYS_Rst);
OBUFT_4 : OBUFT
PORT MAP (
	O => LA(4),
	I => LA_w(4),
	T => SYS_Rst);
OBUFT_5 : OBUFT
PORT MAP (
	O => LA(5),
	I => LA_w(5),
	T => SYS_Rst);
OBUFT_6 : OBUFT
PORT MAP (
	O => LA(6),
	I => LA_w(6),
	T => SYS_Rst);
OBUFT_7 : OBUFT
PORT MAP (
	O => LA(7),
	I => LA_w(7),
	T => SYS_Rst);
OBUFT_8 : OBUFT
PORT MAP (
	O => LA(8),
	I => LA_w(8),
	T => SYS_Rst);
OBUFT_9 : OBUFT
PORT MAP (
	O => LA(9),
	I => LA_w(9),
	T => SYS_Rst);
OBUFT_10 : OBUFT
PORT MAP (
	O => LA(10),
	I => LA_w(10),
	T => SYS_Rst);
OBUFT_11 : OBUFT
PORT MAP (
	O => LA(11),
	I => LA_w(11),
	T => SYS_Rst);
OBUFT_12 : OBUFT
PORT MAP (
	O => LA(12),
	I => LA_w(12),
	T => SYS_Rst);
OBUFT_13 : OBUFT
PORT MAP (
	O => LA(13),
	I => LA_w(13),
	T => SYS_Rst);
OBUFT_14 : OBUFT
PORT MAP (
	O => LA(14),
	I => LA_w(14),
	T => SYS_Rst);
OBUFT_15 : OBUFT
PORT MAP (
	O => LA(15),
	I => LA_w(15),
	T => SYS_Rst);
OBUFT_16 : OBUFT
PORT MAP (
	O => LA(16),
	I => LA_w(16),
	T => SYS_Rst);
OBUFT_17 : OBUFT
PORT MAP (
	O => LA(17),
	I => LA_w(17),
	T => SYS_Rst);
OBUFT_18 : OBUFT
PORT MAP (
	O => LA(18),
	I => LA_w(18),
	T => SYS_Rst);
OBUFT_19 : OBUFT
PORT MAP (
	O => LA(19),
	I => LA_w(19),
	T => SYS_Rst);
OBUFT_20 : OBUFT
PORT MAP (
	O => LA(20),
	I => LA_w(20),
	T => SYS_Rst);
OBUFT_21 : OBUFT
PORT MAP (
	O => LA(21),
	I => LA_w(21),
	T => SYS_Rst);
OBUFT_22 : OBUFT
PORT MAP (
	O => LA(22),
	I => LA_w(22),
	T => SYS_Rst);

-- Date bus in-out buffer
iobuf_0 : IOBUF
PORT MAP (
	O => LD_IN(0),
	I => LD_O_w(0),
	IO => LD(0),
	T => LD_T_w(0));
iobuf_1 : IOBUF
PORT MAP (
	O => LD_IN(1),
	I => LD_O_w(1),
	IO => LD(1),
	T => LD_T_w(1));
iobuf_2 : IOBUF
PORT MAP (
	O => LD_IN(2),
	I => LD_O_w(2),
	IO => LD(2),
	T => LD_T_w(2));
iobuf_3 : IOBUF
PORT MAP (
	O => LD_IN(3),
	I => LD_O_w(3),
	IO => LD(3),
	T => LD_T_w(3));
iobuf_4 : IOBUF
PORT MAP (
	O => LD_IN(4),
	I => LD_O_w(4),
	IO => LD(4),
	T => LD_T_w(4));
iobuf_5 : IOBUF
PORT MAP (
	O => LD_IN(5),
	I => LD_O_w(5),
	IO => LD(5),
	T => LD_T_w(5));
iobuf_6 : IOBUF
PORT MAP (
	O => LD_IN(6),
	I => LD_O_w(6),
	IO => LD(6),
	T => LD_T_w(6));
iobuf_7 : IOBUF
PORT MAP (
	O => LD_IN(7),
	I => LD_O_w(7),
	IO => LD(7),
	T => LD_T_w(7));
iobuf_8 : IOBUF
PORT MAP (
	O => LD_IN(8),
	I => LD_O_w(8),
	IO => LD(8),
	T => LD_T_w(8));
iobuf_9 : IOBUF
PORT MAP (
	O => LD_IN(9),
	I => LD_O_w(9),
	IO => LD(9),
	T => LD_T_w(9));
iobuf_10 : IOBUF
PORT MAP (
	O => LD_IN(10),
	I => LD_O_w(10),
	IO => LD(10),
	T => LD_T_w(10));
iobuf_11 : IOBUF
PORT MAP (
	O => LD_IN(11),
	I => LD_O_w(11),
	IO => LD(11),
	T => LD_T_w(11));
iobuf_12 : IOBUF
PORT MAP (
	O => LD_IN(12),
	I => LD_O_w(12),
	IO => LD(12),
	T => LD_T_w(12));
iobuf_13 : IOBUF
PORT MAP (
	O => LD_IN(13),
	I => LD_O_w(13),
	IO => LD(13),
	T => LD_T_w(13));
iobuf_14 : IOBUF
PORT MAP (
	O => LD_IN(14),
	I => LD_O_w(14),
	IO => LD(14),
	T => LD_T_w(14));
iobuf_15 : IOBUF
PORT MAP (
	O => LD_IN(15),
	I => LD_O_w(15),
	IO => LD(15),
	T => LD_T_w(15));



-- Flash control tri state buffer
FLASH_0 : OBUFT
PORT MAP (
	O => FLASH_CEn,
	I => MEMCON_CEn(1),
	T => SYS_Rst);
FLASH_1 : OBUFT
PORT MAP (
	O => FLASH_OEn,
	I => MEMCON_OEn(1),
	T => SYS_Rst);
FLASH_2 : OBUFT
PORT MAP (
	O => FLASH_WEn,
	I => MEMCON_WEn,
	T => SYS_Rst);
FLASH_3 : OBUFT
PORT MAP (
	O => FLASH_BYTEn,
	I => '1',
	T => SYS_Rst);




-- System reset generate
SYS_Rst <= not ( not SYS_Rst_IN and BUS_REL and DLL_LOCK_o);

 

-- Address bus select
MEMCON_CEn_w <= not MEMCON_CEn(0) or not MEMCON_CEn(1);
LA_w(22)       <= SDRAM_ADR(11);
LA_w(11 to 21) <= MEMCON_ADR(20 to 30) when (MEMCON_CEn_w = '1')
                 else SDRAM_ADR(0 to 10) ;
LA_w(4 to 10)  <= MEMCON_ADR(13 to 19) ;


flnotcompatible : if (COMPATIBLE_32MBIT = '0') generate
	LA_w(0 to 3)   <= MEMCON_ADR(9 to 12) ;
end generate flnotcompatible;


flcompatible : if (COMPATIBLE_32MBIT = '1') generate
	memcon_adr_change(0) <= not MEMCON_ADR(9);
	memcon_adr_change(1 to 3) <= MEMCON_ADR(10 to 12);
	LA_w(0 to 3) <= "0001" when (memcon_adr_change(9 to 12)) = "1000"
	                else "1000" when (MEMCON_ADR(9 to 12)) = "0001"
	                else  MEMCON_ADR(9 to 12);
end generate flcompatible;


-- data bus select
LD_O_w <= MEMCON_DQ_O(0 to 15) when MEMCON_CEn_w ='1' else SDRAM_DQ_O;
LD_T_w(15) <= (MEMCON_DQ_T(15) and SDRAM_DQ_T(15)) or SYS_Rst;
LD_T_w(14) <= (MEMCON_DQ_T(14) and SDRAM_DQ_T(14)) or SYS_Rst;
LD_T_w(13) <= (MEMCON_DQ_T(13) and SDRAM_DQ_T(13)) or SYS_Rst;
LD_T_w(12) <= (MEMCON_DQ_T(12) and SDRAM_DQ_T(12)) or SYS_Rst;
LD_T_w(11) <= (MEMCON_DQ_T(11) and SDRAM_DQ_T(11)) or SYS_Rst;
LD_T_w(10) <= (MEMCON_DQ_T(10) and SDRAM_DQ_T(10)) or SYS_Rst;
LD_T_w(9) <= (MEMCON_DQ_T(9) and SDRAM_DQ_T(9)) or SYS_Rst;
LD_T_w(8) <= (MEMCON_DQ_T(8) and SDRAM_DQ_T(8)) or SYS_Rst;
LD_T_w(7) <= (MEMCON_DQ_T(7) and SDRAM_DQ_T(7)) or SYS_Rst;
LD_T_w(6) <= (MEMCON_DQ_T(6) and SDRAM_DQ_T(6)) or SYS_Rst;
LD_T_w(5) <= (MEMCON_DQ_T(5) and SDRAM_DQ_T(5)) or SYS_Rst;
LD_T_w(4) <= (MEMCON_DQ_T(4) and SDRAM_DQ_T(4)) or SYS_Rst;
LD_T_w(3) <= (MEMCON_DQ_T(3) and SDRAM_DQ_T(3)) or SYS_Rst;
LD_T_w(2) <= (MEMCON_DQ_T(2) and SDRAM_DQ_T(2)) or SYS_Rst;
LD_T_w(1) <= (MEMCON_DQ_T(1) and SDRAM_DQ_T(1)) or SYS_Rst;
LD_T_w(0) <= (MEMCON_DQ_T(0) and SDRAM_DQ_T(0)) or SYS_Rst;
SDRAM_DQ_I <= LD_IN;
MEMCON_DQ_I(0 to 15) <= LD_IN ;



-- Mac control signal
MAC_AEN <= '0';
MAC_WRn <= not (not MEMCON_WEn  and  not MEMCON_CEn(0));
MAC_RDn <= not (not MEMCON_OEn(0)  and  not MEMCON_CEn(0));
MAC_BEn <= MEMCON_BEn(0 to 1);
MAC_ADSn <= '0';

-- TE7720 control signal
BUS_REQ <= '1';

-- GPIO
GPIO_IO_0_I(2) <= GPIO_IO_0_O(2);
GPIO_IO_0_I(1) <= COMPATIBLE_32MBIT;
GPIO_IO_0_I(0) <= BOOTMODE;

iobuf_reset : IOBUF
PORT MAP (
	I => GPIO_IO_0_O(2),
	IO => FPGA_RESET_EN,
	T => SYS_Rst);





RESERVE_COLLECT <= FLASH_RnB and MAC_ARDY;



END IMP ;
