/*
 * main.c
 *
 * Copyright (C) 2004-2005 Atmark Techno, Inc.  All Rights Reserved.
 *
 */

#include <ctype.h>

#include "version.h"
#include "memmap.h"
#include "srec.h"
#include "flash.h"
#include "medium.h"

#define MAX_BUFFER_SIZE 64

#define FLASH_4MiB (0x16)
#define FLASH_8MiB (0x17)
#define BOOTLOADER_OFFSET_4MiB_FLASH (0x00080000)
#define BOOTLOADER_OFFSET_8MiB_FLASH (0x00100000)

static int download(void)
{
        char buffer[MAX_BUFFER_SIZE];
        char *ptr1, *ptr2;
        unsigned int total_len;

        while(1)
        {
                get_line(buffer, MAX_BUFFER_SIZE);

                /* Chew through any leading white space */
                ptr1=buffer;
                while(*ptr1&& isspace(*ptr1))
                        ptr1++;
        
                /* And truncate any trailing white space */
                ptr2=ptr1;
                while(*ptr2 && !isspace(*ptr2))
                        ptr2++;
                *ptr2='\0';


                total_len += srec_decode_line(ptr1);
                put_char('.');
        }

        return 0;
}

static unsigned int is_autoboot_mode(void)
{
        return *(volatile unsigned int *)(SYSTEM_REGISTER_BASEADDR) & SYSTEM_REGISTER_BOOT_MODE;
}

static unsigned int is_compatible_mode(void)
{
        return *(volatile unsigned int *)(SYSTEM_REGISTER_BASEADDR) & SYSTEM_REGISTER_COMPATIBLE_MODE;
}

#define JUMP(addr) { ((void(*)(void))(addr))(); }

static void second_bootloader(unsigned int offset)
{
        flash_copy_to_dram(offset);
        myprint("Switching to 2nd stage bootloader...\n\r");
        JUMP(BBOOT_LOAD_ADDRESS); /* Never returns */
}

int main(void)
{
        unsigned int bootloader_offset;

        switch(flash_get_size()) {
        case FLASH_4MiB:
                bootloader_offset = BOOTLOADER_OFFSET_4MiB_FLASH;
                break;
        case FLASH_8MiB:
                if (is_compatible_mode())
                        bootloader_offset = BOOTLOADER_OFFSET_4MiB_FLASH;
                else
                        bootloader_offset = BOOTLOADER_OFFSET_8MiB_FLASH;
                break;
        default:
                myprint("Unknown flash size\n\r");
                goto halt;
                break;
        }

        if (is_autoboot_mode()) {
                second_bootloader(bootloader_offset);
        }

        myprint("\n\r\n\rWelcome to " BBOOT_NAME " v" BBOOT_VERSION " (" TARGET_CPU ")\n\r");
        myprint(BBOOT_DESC "\n\r\n\r");
        myprint("hit Enter key to activate second stage bootloader or\n\r");
        myprint("hit 'S' key to download S-Record\n\r");
        while (1) {
                char key;

                key = get_char();
                if ((key == 's') || (key == 'S')) {
                        myprint("Erasing Flash...");
                        flash_erase(bootloader_offset);
                        myprint("Done\n\r");
                        myprint("Start sending S-Record!!\n\r");
                        download(); /* never returns */
                }
                else if (key == '\r') {
                        second_bootloader(bootloader_offset); /* never returns */
                }
                else {
                        myprint("Please hit 'S' or Enter key\n\r");
                }
        }

halt:
        myprint("Halting...\n\r");
        return 0;
}
